@@ -125,6 +125,18 @@ namespace Imendio.Blam {
 	    }
 	}
 
+	public Item GetSelected ()
+	{
+	    TreeIter  iter;
+	    TreeModel model;
+
+	    if (!this.Selection.GetSelected (out model, out iter)) {
+		return null;
+	    }
+
+	    return (Item) model.GetValue (iter, 0);
+	}
+	
 	private void SelectionChanged (object obj, EventArgs args)
 	{
 	    TreeSelection selection = (TreeSelection) obj;
